<?php

namespace App\Dto\Output;

use ApiPlatform\Metadata\Get;
use App\Entity\Image;
use Symfony\Component\Serializer\Annotation\Groups;

#[Get(shortName: 'Image')]
final class ImageOutput extends AbstractOutput
{
    #[Groups(['image:read'])]
    public ?string $name = '';

    #[Groups(['image:read'])]
    public ?string $description = '';

    #[Groups(['image:read'])]
    public ?string $comments = '';

    #[Groups(['image:read'])]
    public ?string $type = null;

    #[Groups(['image:read'])]
    public ?string $path = '';

    #[Groups(['image:read'])]
    public ?string $revision = '';

    #[Groups(['image:read'])]
    public ?string $info = '';

    #[Groups(['image:read'])]
    public ?int $size = null;

    #[Groups(['image:read'])]
    public ?ClientOutput $clientOutput = null;

    #[Groups(['image:read'])]
    public ?SoftwareProfileOutput $softwareProfile = null;

    #[Groups(['image:read'])]
    public ?OrganizationalUnitOutput $organizationalUnit = null;

    public function __construct(Image $image)
    {
        parent::__construct($image);

        $this->name = $image->getName();
        $this->description = $image->getDescription();
        $this->comments = $image->getComments();
        $this->type = $image->getType();
        $this->path = $image->getPath();
        $this->revision = $image->getRevision();
        $this->info = $image->getInfo();
        $this->size = $image->getSize();
        $this->clientOutput = $image->getClient() ? new ClientOutput($image->getClient()) : null;
        $this->softwareProfile = $image->getSoftwareProfile() ? new SoftwareProfileOutput($image->getSoftwareProfile()) : null;
        $this->organizationalUnit = $image->getOrganizationalUnit() ? new OrganizationalUnitOutput($image->getOrganizationalUnit()) : null;
    }
}